Chemics
=======

The `Chemics <https://pypi.org/project/chemics/>`_ package is a collection of Python functions for performing calculations in the field of chemical engineering. Source code for the package is available on `GitHub <https://github.com/wigging/chemics>`_ and contributions from the community are encouraged.

.. toctree::
   :maxdepth: 1
   :caption: Getting started

   installation
   contributing

.. toctree::
   :maxdepth: 1
   :caption: Examples

   examples/biomass_composition
   examples/chemical_equation
   examples/conversions
   examples/dimensionless
   examples/gas_properties
   examples/gas_mixture
   examples/analysis
   examples/pyrolysis_number
   examples/wood_properties

.. toctree::
   :maxdepth: 1
   :caption: API documentation

   api/atm_pressure
   api/atomic_elements
   api/biomass_composition
   api/chemical_equation
   api/conversions
   api/dimensionless_numbers
   api/gas
   api/gas_mixture
   api/liquid
   api/molecular_weight
   api/proximate_analysis
   api/ultimate_analysis
   api/wood

Package index and modules
-------------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
